mocktail_image_network library
A Dart package which allows you to mock Image.network in your widget tests with confidence using mocktail.
Functions
-
mockNetworkImages<
T> (T body(), {Uint8List? imageBytes, ImageResolver? imageResolver}) → T -
Utility method that allows you to execute a widget test when you pump a
widget that contains an
Image.networknode in its tree.
Typedefs
-
ImageResolver
= List<
int> Function(Uri uri) -
Signature for a function that returns a
List<int>for a given Uri.